Structs
- Query
Root - A simple GraphQL Query root for demonstration. In a real scenario, this would be constructed dynamically or composed of multiple Query roots.
Functions
- build_
schema - Helper to build a basic Ferrox GraphQL schema without mutations or subscriptions
- build_
schema_ with_ context - Helper to build a GraphQL schema with a Repository injected into its context
- export_
sdl - Helper to export the GraphQL Schema (SDL) to a file for Frontend Code Generation
- setup